# autoqtl

[![Logo](./docs/FinalLogo_Big.png)]()

AutoQTL : Automated Quantitative Trait Locus Analysis
==================================

**AutoQTL** is an automated machine learning tool for QTL analysis.
The goal of AutoQTL is to automate QTL analysis by building an analytics pipeline optimized for explaining variation in a quantitative trait given a set of genetic variants. It uses genetic programming (GP) as the search and optimization method. 

AutoQTL is recommended to be used as a posthoc analysis to genome-wide association/QTL analysis. AutoQTL aims to provide additional insights into the association of phenotype to genotype including, but not limited to, the detection of non-additive genetic inheritance models and epistatic interactions. Furthermore, our feature importance metrics, in tandem with summary statistics, can provide additional evidence for the identification of putative QTL and targets for gene set enrichment and KEGG pathway analysis. 

#geneticsmeetsautoML

Running AutoQTL
==================================
Anyone interested in AutoQTL can clone the repository and run the autoqtl_test.py file in the 'test' folder in a python environment made by using the requirements.txt file.
This software is built as part of a proof-of-concept and hence is still under development. 
 
We continue to work on to add new features and functionality to AutoQTL and make it available as a python package. 
Suggestions are welcome.

Citing AutoQTL
==================================
If you use AutoQTL in a scientific publication, please consider citing the following paper:

Philip J. Freda, Attri Ghosh, Elizabeth Zhang, Tianhao Luo, Apurva S. Chitre, Oksana Polesskaya, Celine L. St. Pierre, Jianjun Gao,
Connor D. Martin, Hao Chen, Angel G. Garcia-Martinez, Tengfei Wang, Wenyan Han, Keita Ishiwari, Paul Meyer, Alexander Lamparelli,
Christopher P. King, Abraham A. Palmer, Ruowang Li and Jason H. Moore. [Automated quantitative trait locus analysis (AutoQTL)](https://biodatamining.biomedcentral.com/articles/10.1186/s13040-023-00331-3). *BioData Mining* 16, Article number: 14 (2023)

